@@ -13,6 +13,7 @@
 #include "settings.h"
 
 #include "core/kget.h"
+#include "core/signature.h"
 #include "core/verifier.h"
 
 #include <cmath>
@@ -44,6 +45,7 @@ DataSourceFactory::DataSourceFactory(QObject *parent, const KUrl &dest, KIO::fil
     m_downloadedSize(0),
     m_segSize(segSize),
     m_speed(0),
+    m_percent(0),
     m_tempOffset(0),
     m_startedChunks(0),
     m_finishedChunks(0),
@@ -115,6 +117,14 @@ void DataSourceFactory::deinit()
     }
 }
 
+void DataSourceFactory::synchronDeinit()
+{
+    if (m_downloadInitialized && QFile::exists(m_dest.toLocalFile())) {
+        KIO::Job *del = KIO::del(m_dest, KIO::HideProgressInfo);
+        KIO::NetAccess::synchronousRun(del, 0);
+    }
+}
+
 void DataSourceFactory::findFileSize()
 {
     kDebug(5001) << "Find the filesize" << this;
@@ -138,7 +148,7 @@ void DataSourceFactory::slotFoundFileSize(TransferDataSource *source, KIO::files
 {
     m_size = fileSize;
     kDebug(5001) << source << "found size" << m_size << "and is assigned segments" << segmentRange << this;
-    emit totalSize(m_size);
+    emit dataSourceFactoryChange(Transfer::Tc_TotalSize);
 
     init();
 
@@ -274,7 +284,7 @@ void DataSourceFactory::start()
             if (!mountPoint.isNull()) {
                 if (mountPoint->mountType() == "vfat") {//TODO check what is reported on Windows for vfat
                     stop();
-                    kError(5001) << "Filesize is larger than maximum file size supported by VFAT.";
+                    KMessageBox::error(0, i18n("Filesize is larger than maximum file size supported by VFAT."), i18n("Error"));
                     return;
                 }
             }
@@ -304,7 +314,7 @@ void DataSourceFactory::open(KIO::Job *job)
     }
 
     connect(m_putJob, SIGNAL(position(KIO::Job*,KIO::filesize_t)), this, SLOT(slotOffset(KIO::Job*,KIO::filesize_t)));
-    connect(m_putJob, SIGNAL(written(KIO::Job*, KIO::filesize_t)), this, SLOT(slotDataWritten(KIO::Job*,KIO::filesize_t)));
+    connect(m_putJob, SIGNAL(written(KIO::Job*,KIO::filesize_t)), this, SLOT(slotDataWritten(KIO::Job*,KIO::filesize_t)));
     m_open = true;
 
     if (m_startTried)
@@ -431,11 +441,12 @@ void DataSourceFactory::addMirror(const KUrl &url, bool used, int numParalellCon
                     }
 
                     connect(source, SIGNAL(capabilitiesChanged()), this, SLOT(slotUpdateCapabilities()));
-                    connect(source, SIGNAL(brokenSegments(TransferDataSource*,QPair<int, int>)), this, SLOT(brokenSegments(TransferDataSource*,QPair<int, int>)));
-                    connect(source, SIGNAL(broken(TransferDataSource*, TransferDataSource::Error)), this, SLOT(broken(TransferDataSource*,TransferDataSource::Error)));
+                    connect(source, SIGNAL(brokenSegments(TransferDataSource*,QPair<int,int>)), this, SLOT(brokenSegments(TransferDataSource*,QPair<int,int>)));
+                    connect(source, SIGNAL(broken(TransferDataSource*,TransferDataSource::Error)), this, SLOT(broken(TransferDataSource*,TransferDataSource::Error)));
                     connect(source, SIGNAL(finishedSegment(TransferDataSource*,int,bool)), this, SLOT(finishedSegment(TransferDataSource*,int,bool)));
-                    connect(source, SIGNAL(data(KIO::fileoffset_t, const QByteArray&, bool&)), this, SLOT(slotWriteData(KIO::fileoffset_t, const QByteArray&, bool&)));
+                    connect(source, SIGNAL(data(KIO::fileoffset_t,QByteArray,bool&)), this, SLOT(slotWriteData(KIO::fileoffset_t,QByteArray,bool&)));
                     connect(source, SIGNAL(freeSegments(TransferDataSource*,QPair<int,int>)), this, SLOT(slotFreeSegments(TransferDataSource*,QPair<int,int>)));
+                    connect(source, SIGNAL(log(QString,Transfer::LogLevel)), this, SIGNAL(log(QString,Transfer::LogLevel)));
 
                     slotUpdateCapabilities();
 
@@ -744,7 +755,7 @@ void DataSourceFactory::slotDataWritten(KIO::Job *job, KIO::filesize_t written)
     if (written == tempSize)//TODO if not same cache it temporarly!
     {
         m_downloadedSize += written;
-        emit processedSize((m_downloadedSize));
+        emit dataSourceFactoryChange(Transfer::Tc_DownloadedSize);
 //             m_tempCache.clear();
     }
 
@@ -761,7 +772,8 @@ void DataSourceFactory::slotDataWritten(KIO::Job *job, KIO::filesize_t written)
 void DataSourceFactory::slotPercent(KJob* job, ulong p)
 {
     Q_UNUSED(job)
-    emit percent(p);
+    m_percent = p;
+    emit dataSourceFactoryChange(Transfer::Tc_Percent);
 }
 
 void DataSourceFactory::speedChanged()
@@ -772,10 +784,12 @@ void DataSourceFactory::speedChanged()
     if(m_prevDownloadedSizes.size() > 10)
         m_prevDownloadedSizes.removeFirst();
 
-    emit speed(m_speed);
-    if (m_size) {
-        emit percent(m_downloadedSize * 100 / m_size);
-    }
+    ulong percent = (m_size ? (m_downloadedSize * 100 / m_size) : 0);
+    const bool percentChanged = (percent != m_percent);
+    m_percent = percent;
+
+    Transfer::ChangesFlags change = (percentChanged ? (Transfer::Tc_DownloadSpeed | Transfer::Tc_Percent) : Transfer::Tc_DownloadSpeed);
+    emit dataSourceFactoryChange(change);
 }
 
 void DataSourceFactory::killPutJob()
@@ -842,8 +856,8 @@ void DataSourceFactory::startMove()
     killPutJob();
 
     KIO::Job *move = KIO::file_move(m_dest, m_newDest, -1, KIO::HideProgressInfo);
-    connect(move, SIGNAL(result(KJob *)), this, SLOT(newDestResult(KJob *)));
-    connect(move, SIGNAL(percent(KJob*, unsigned long)), this, SLOT(slotPercent(KJob*, ulong)));
+    connect(move, SIGNAL(result(KJob*)), this, SLOT(newDestResult(KJob*)));
+    connect(move, SIGNAL(percent(KJob*,ulong)), this, SLOT(slotPercent(KJob*,ulong)));
 
     m_dest = m_newDest;
     verifier()->setDestination(m_dest);
@@ -880,14 +894,17 @@ void DataSourceFactory::slotRepair(const QList<KIO::fileoffset_t> &offsets, KIO:
 {
     disconnect(verifier(), SIGNAL(brokenPieces(QList<KIO::fileoffset_t>,KIO::filesize_t)), this, SLOT(slotRepair(QList<KIO::fileoffset_t>,KIO::filesize_t)));
 
-    if (offsets.isEmpty())
+    if (!m_startedChunks || !m_finishedChunks)
     {
         kDebug(5001) << "Redownload everything";
-        m_startedChunks->clear();
-        m_finishedChunks->clear();
+        m_downloadedSize = 0;
     }
     else
     {
+        if (offsets.isEmpty()) {
+            m_startedChunks->clear();
+            m_finishedChunks->clear();
+        }
         kDebug(5001) << "Redownload broken pieces";
         for (int i = 0; i < offsets.count(); ++i) {
             const int start = offsets[i] / m_segSize;
@@ -895,7 +912,11 @@ void DataSourceFactory::slotRepair(const QList<KIO::fileoffset_t> &offsets, KIO:
             m_startedChunks->setRange(start, end, false);
             m_finishedChunks->setRange(start, end, false);
         }
+
+        m_downloadedSize = m_segSize * m_finishedChunks->numOnBits();
     }
+    m_prevDownloadedSizes.clear();
+    m_prevDownloadedSizes.append(m_downloadedSize);
 
     //remove all current mirrors and readd the first unused mirror
     const QList<KUrl> mirrors = m_sources.keys();//FIXME only remove the mirrors of the broken segments?! --> for that m_assignedChunks would need to be saved was well
@@ -905,15 +926,14 @@ void DataSourceFactory::slotRepair(const QList<KIO::fileoffset_t> &offsets, KIO:
     }
     addMirror(m_unusedUrls.takeFirst(), true, m_unusedConnections.takeFirst());
 
-    m_downloadedSize = m_segSize * m_finishedChunks->numOnBits();
-    m_prevDownloadedSizes.clear();
-    m_prevDownloadedSizes.append(m_downloadedSize);
+    m_speed = 0;
 
-    emit speed(0);
-    emit processedSize(m_downloadedSize);
+    Transfer::ChangesFlags change = (Transfer::Tc_DownloadSpeed | Transfer::Tc_DownloadedSize);
     if (m_size) {
-        emit percent((m_downloadedSize * 100) / m_size);
+        change |= Transfer::Tc_Percent;
+        m_percent = (m_downloadedSize * 100 / m_size);
     }
+    emit dataSourceFactoryChange(change);
     m_status = Job::Stopped;
 
     start();
@@ -941,9 +961,11 @@ void DataSourceFactory::load(const QDomElement *element)
     verifier()->load(e);
     signature()->load(e);
 
+    Transfer::ChangesFlags change = Transfer::Tc_None;
+
     if (!m_size) {
         m_size = e.attribute("size").toULongLong();
-        emit totalSize(m_size);
+        change |= Transfer::Tc_TotalSize;
     }
     KIO::fileoffset_t tempSegSize = e.attribute("segementSize").toLongLong();
     if (tempSegSize)
@@ -952,9 +974,10 @@ void DataSourceFactory::load(const QDomElement *element)
     }
     if (!m_downloadedSize) {
         m_downloadedSize = e.attribute("processedSize").toULongLong();
-        emit processedSize(m_downloadedSize);
+        change |= Transfer::Tc_DownloadedSize;
         if (m_size) {
-            emit percent((m_downloadedSize * 100) / m_size);
+            m_percent = (m_downloadedSize * 100 / m_size);
+            change |= Transfer::Tc_Percent;
         }
     }
     if (e.hasAttribute("doDownload"))
@@ -1028,38 +1051,41 @@ void DataSourceFactory::load(const QDomElement *element)
     }
 
     m_status = static_cast<Job::Status>(e.attribute("status").toInt());
+
+    if (change != Transfer::Tc_None) {
+        emit dataSourceFactoryChange(change);
+    }
 }
 
 void DataSourceFactory::changeStatus(Job::Status status)
 {
+    Transfer::ChangesFlags change = Transfer::Tc_Status;
     m_status = status;
+
     switch (m_status)
     {
         case Job::Aborted:
         case Job::Moving:
         case Job::Stopped:
             m_speed = 0;
-            emit speed(m_speed);
+            change |= Transfer::Tc_DownloadSpeed;
             break;
         case Job::Running:
             break;
         case Job::Finished:
             m_speed = 0;
+            m_percent = 100;
 
-            if (m_size)
-            {
+            if (m_size) {
                 m_downloadedSize = m_size;
-                emit processedSize(m_downloadedSize);
-            }
-            else if (m_downloadedSize)
-            {
+                change |= Transfer::Tc_DownloadedSize;
+            } else if (m_downloadedSize) {
                 m_sizeFoundOnFinish = true;
                 m_size = m_downloadedSize;
-                emit totalSize(m_size);
+                change |= Transfer::Tc_TotalSize;
             }
 
-            emit speed(0);
-            emit percent(100);
+            change |= Transfer::Tc_DownloadSpeed | Transfer::Tc_Percent;
 
             if (Settings::checksumAutomaticVerification() && verifier()->isVerifyable()) {
                 verifier()->verify();
@@ -1075,7 +1101,7 @@ void DataSourceFactory::changeStatus(Job::Status status)
             break;
     }
 
-    emit statusChanged(m_status);
+    emit dataSourceFactoryChange(change);
 }
 
 void DataSourceFactory::save(const QDomElement &element)
@@ -1183,51 +1209,6 @@ bool DataSourceFactory::isValid() const
     return valid;
 }
 
-KIO::filesize_t DataSourceFactory::size() const
-{
-    return m_size;
-}
-
-KIO::filesize_t DataSourceFactory::downloadedSize() const
-{
-    return m_downloadedSize;
-}
-
-ulong DataSourceFactory::currentSpeed() const
-{
-    return m_speed;
-}
-
-KUrl DataSourceFactory::dest() const
-{
-    return m_dest;
-}
-
-int DataSourceFactory::maxMirrorsUsed() const
-{
-    return m_maxMirrorsUsed;
-}
-
-void DataSourceFactory::setMaxMirrorsUsed(int maxMirrorsUsed)
-{
-    m_maxMirrorsUsed = maxMirrorsUsed;
-}
-
-bool DataSourceFactory::doDownload() const
-{
-    return m_doDownload;
-}
-
-Job::Status DataSourceFactory::status() const
-{
-    return m_status;
-}
-
-bool DataSourceFactory::downloadInitialized() const
-{
-    return m_downloadInitialized;
-}
-
 Verifier *DataSourceFactory::verifier()
 {
     if (!m_verifier) {
@@ -1246,27 +1227,26 @@ Signature *DataSourceFactory::signature()
     return m_signature;
 }
 
-Transfer::Capabilities DataSourceFactory::capabilities() const
-{
-    return m_capabilities;
-}
-
 void DataSourceFactory::slotUpdateCapabilities()
 {
     const Transfer::Capabilities oldCaps = capabilities();
     Transfer::Capabilities newCaps = 0;
 
-    foreach (TransferDataSource *source, m_sources) {
-        if (!source->assignedSegments().isEmpty()) {
-            if (newCaps) {
-                newCaps &= source->capabilities();
-            } else {
-                newCaps = source->capabilities();
+    if ((status() == Job::Finished) || (status() == Job::Stopped)) {
+        newCaps |= Transfer::Cap_Moving | Transfer::Cap_Renaming;
+    } else {
+        foreach (TransferDataSource *source, m_sources) {
+            if (!source->assignedSegments().isEmpty()) {
+                if (newCaps) {
+                    newCaps &= source->capabilities();
+                } else {
+                    newCaps = source->capabilities();
+                }
             }
         }
     }
 
-    if ((newCaps & Transfer::Cap_Resuming) || (status() == Job::Finished) || (status() == Job::Stopped)) {
+    if (newCaps & Transfer::Cap_Resuming) {
         newCaps |= Transfer::Cap_Moving | Transfer::Cap_Renaming;
     }
 
