@@ -44,7 +44,7 @@ TransferHistoryItem::TransferHistoryItem() : QObject()
 
 TransferHistoryItem::TransferHistoryItem(const Transfer &transfer) : QObject()
 {
-    setDest(transfer.dest().url());
+    setDest(transfer.dest().pathOrUrl());
     setSource(transfer.source().url());
     setSize(transfer.totalSize());
     setDateTime(QDateTime::currentDateTime());
@@ -228,7 +228,6 @@ void XmlStore::DeleteThread::run()
     QString error;
     int line;
     int column;
-    int total;
 
     if (!doc.setContent(&file, &error, &line, &column)) 
     {
@@ -238,7 +237,6 @@ void XmlStore::DeleteThread::run()
     file.close();
 
     QDomElement root = doc.documentElement();
-    total = root.childNodes().size();
 
     QDomNodeList list = root.elementsByTagName("Transfer");
 
@@ -302,6 +300,7 @@ void XmlStore::LoadThread::run()
     for (int i = 0 ; i < nItems ; i++)
     {
         QDomElement dom = list.item(i).toElement();
+        
         TransferHistoryItem item;
         item.setDest(dom.attribute("Dest"));
         item.setSource(dom.attribute("Source"));
@@ -313,10 +312,6 @@ void XmlStore::LoadThread::run()
     }
     doc.clear();
     file.close();
-    TransferHistoryItem item;
-
-    emit elementLoaded(total, total, item);
-    kDebug(5001) << "Load file" << m_url;
 }
 
 XmlStore::XmlStore(const QString &url) : TransferHistoryStore(),
@@ -353,10 +348,10 @@ void XmlStore::load()
     m_loadThread = new XmlStore::LoadThread(this, m_storeUrl);
 
     connect(m_loadThread, SIGNAL(finished()), SIGNAL(loadFinished()));
-    connect(m_loadThread, SIGNAL(elementLoaded(int, int, const TransferHistoryItem &)),
-                        SIGNAL(elementLoaded(int, int, const TransferHistoryItem &)));
-    connect(m_loadThread, SIGNAL(elementLoaded(int, int, const TransferHistoryItem &)),
-                        SLOT(slotLoadElement(int, int, const TransferHistoryItem &)));
+    connect(m_loadThread, SIGNAL(elementLoaded(int,int,TransferHistoryItem)),
+                        SIGNAL(elementLoaded(int,int,TransferHistoryItem)));
+    connect(m_loadThread, SIGNAL(elementLoaded(int,int,TransferHistoryItem)),
+                        SLOT(slotLoadElement(int,int,TransferHistoryItem)));
     m_loadThread->start();
 }
 
@@ -370,8 +365,8 @@ void XmlStore::saveItem(const TransferHistoryItem &item)
     m_saveThread = new XmlStore::SaveThread(this, m_storeUrl, item);
 
     connect(m_saveThread, SIGNAL(finished()), SIGNAL(saveFinished()));
-    connect(m_saveThread, SIGNAL(elementLoaded(int, int, const TransferHistoryItem &)),
-                        SIGNAL(elementLoaded(int, int, const TransferHistoryItem &)));
+    connect(m_saveThread, SIGNAL(elementLoaded(int,int,TransferHistoryItem)),
+                        SIGNAL(elementLoaded(int,int,TransferHistoryItem)));
     m_saveThread->start();
 }
 
