@@ -2,6 +2,7 @@
 
    Copyright (C) 2006 Dario Massarin <nekkar@libero.it>
    Copyright (C) 2009 Lukas Appelhans <l.appelhans@gmx.de>
+   Copyright (C) 2010 Matthias Fuchs <mat69@gmx.net>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +27,24 @@
 #include <klocale.h>
 #include <KMimeType>
 
-#include <qmimedata.h>
+ItemMimeData::ItemMimeData()
+  : QMimeData()
+{
+}
+
+ItemMimeData::~ItemMimeData()
+{
+}
+
+void ItemMimeData::appendTransfer(const QWeakPointer<TransferHandler> &transfer)
+{
+    m_transfers.append(transfer);
+}
+
+QList<QWeakPointer<TransferHandler> > ItemMimeData::transfers() const
+{
+    return m_transfers;
+}
 
 ModelItem::ModelItem(Handler * handler)
   : QStandardItem(),
@@ -213,15 +231,14 @@ void TransferTreeModel::delGroup(TransferGroup * group)
     }
     delTransfers(transfers);
 
-    takeRow(item->row());
+    m_transferGroups.removeAll(item);
+    removeRow(item->row());
 
     m_changedGroups.removeAll(group->handler());
 
     emit groupRemovedEvent(group->handler());
 
     KGet::m_scheduler->delQueue(group);
-
-    m_transferGroups.removeAll(item);
 }
 
 void TransferTreeModel::addTransfers(const QList<Transfer*> &transfers, TransferGroup *group)
@@ -416,6 +433,15 @@ void TransferTreeModel::moveTransfer(Transfer * transfer, TransferGroup * destGr
     KGet::selectionModel()->clearSelection();
 }
 
+void TransferTreeModel::moveTransfer(TransferHandler *transfer, TransferGroupHandler *destGroup, TransferHandler *after)
+{
+    Transfer *afterTransfer = 0;
+    if (after) {
+        afterTransfer = after->m_transfer;
+    }
+    moveTransfer(transfer->m_transfer, destGroup->m_group, afterTransfer);
+}
+
 QList<TransferGroup *> TransferTreeModel::transferGroups()
 {
     QList<TransferGroup*> transferGroups;
@@ -538,32 +564,26 @@ Qt::DropActions TransferTreeModel::supportedDropActions() const
 QStringList TransferTreeModel::mimeTypes() const
 {
     QStringList types;
-    types << "application/vnd.text.list";
+    types << "kget/transfer_pointer";
     return types;
 }
 
 QMimeData * TransferTreeModel::mimeData(const QModelIndexList &indexes) const
 {
-    QMimeData * mimeData = new QMimeData();
-    QByteArray encodedData;
-
-    QDataStream stream(&encodedData, QIODevice::WriteOnly);
+    ItemMimeData *mimeData = new ItemMimeData();
 
     QModelIndexList sortedIndexes = indexes;
     qSort(sortedIndexes.begin(), sortedIndexes.end(), qGreater<QModelIndex>());
-    foreach (const QModelIndex &index, sortedIndexes) 
-    {
-        if (index.isValid())
-        {
-            if(index.column() == 0 && index.parent().isValid())
-            {
-                stream << data(index.parent(), Qt::DisplayRole).toString();
-                stream << QString::number((qulonglong) itemFromIndex(index)->handler(), 16);
+    foreach (const QModelIndex &index, sortedIndexes) {
+        if (index.isValid() && index.column() == 0 && index.parent().isValid()) {
+            ModelItem *item = itemFromIndex(index);
+            if (!item->isGroup()) {
+                mimeData->appendTransfer(QWeakPointer<TransferHandler>(item->asTransfer()->transferHandler()));
             }
         }
     }
 
-    mimeData->setData("application/vnd.text.list", encodedData);
+    mimeData->setData("kget/transfer_pointer", QByteArray());
     return mimeData;
 }
 
@@ -572,57 +592,46 @@ bool TransferTreeModel::dropMimeData(const QMimeData * mdata, Qt::DropAction act
     if (action == Qt::IgnoreAction)
         return true;
 
-    if (!mdata->hasFormat("application/vnd.text.list"))
+    const ItemMimeData *itemData = qobject_cast<const ItemMimeData*>(mdata);
+    if (!itemData) {
+        kWarning(5001) << "Unsuported mime data dropped.";
         return false;
+    }
+
+    TransferGroup *destGroup = findGroup(data(parent, Qt::DisplayRole).toString());
+    if (!destGroup) {
+        kWarning(5001) << "No group could be found where the transfers should be inserted to.";
+        return false;
+    }
 
     if (parent.isValid())
         kDebug(5001) << "TransferTreeModel::dropMimeData" << " " << row << " " 
                                                           << column << endl;
 
-    QByteArray encodedData = mdata->data("application/vnd.text.list");
-    QDataStream stream(&encodedData, QIODevice::ReadOnly);
-    QStringList stringList;
-    int rows = 0;
-
-    while (!stream.atEnd()) 
-    {
-        QString text;
-        stream >> text;
-        stringList << text;
-        ++rows;
-    }
-
-    kDebug(5001) << "TransferTreeModel::dropMimeData    DATA:";
-    kDebug(5001) << stringList;
-
+    QList<QWeakPointer<TransferHandler> > transfers = itemData->transfers();
+    kDebug(5001) << "TransferTreeModel::dropMimeData:" << transfers.count() << "transfers.";
 
+    const bool droppedInsideGroup = parent.isValid();
     Transfer * after = 0;
-    for(int i=0; i < rows; i++)
-    {
-//         TransferGroup * group = findGroup(stringList[i]);
+    for (int i = 0; i < transfers.count(); ++i) {
+        bool b = destGroup->size() > row && row - 1 >= 0;
+        if (b)
+            kDebug(5001) << "TRANSFER AFTER:" << destGroup->operator[](row - 1)->source();
+        else
+            kDebug(5001) << "TRANSFER AFTER NOT EXISTING";
 
-//         TransferGroup * destGroup = static_cast<TransferGroup *>(index(row, column, parent).internalPointer());
-
-        TransferGroup * destGroup = findGroup(data(parent, Qt::DisplayRole).toString());
-
-        TransferHandler * transferHandler = (TransferHandler *) stringList[++i].toInt(0, 16);
-        
-        if (destGroup) {
-            bool b = destGroup->size() > row && row - 1 >= 0;
-            if (b)
-                kDebug(5001) << "TRANSFER AFTER:" << destGroup->operator[](row - 1)->source();
-            else
-                kDebug(5001) << "TRANSFER AFTER NOT EXISTING";
-
-            if (!after) {
-                bool droppedInsideGroup = parent.isValid();
-                bool rowValid = (row - 1 >= 0) && (destGroup->size() >= row);
-                if (droppedInsideGroup && rowValid) {
-                    after = destGroup->operator[](row - 1);//insert at the correct position
-                }
+        if (!after) {
+            bool rowValid = (row - 1 >= 0) && (destGroup->size() >= row);
+            if (droppedInsideGroup && rowValid) {
+                after = destGroup->operator[](row - 1);//insert at the correct position
             }
-            moveTransfer(transferHandler->m_transfer, destGroup, after);
-         }
+        }
+
+        if (transfers[i].isNull()) {
+            kWarning() << "The moved transfer has been deleted inbetween.";
+        } else {
+            moveTransfer(transfers[i].data()->m_transfer, destGroup, after);
+        }
     }
     return true;
 }
