@@ -49,6 +49,7 @@
 #include "kopetepluginmanager.h"
 #include "kopeteprotocol.h"
 #include "kopetepicture.h"
+#include "kopeteactivenotification.h"
 
 const int CHAIN_COUNT = 3;
 
@@ -58,6 +59,7 @@ public:
 	Kopete::ContactPtrList contacts;
 	const Kopete::Contact *mUser;
 	QMap<const Kopete::Contact *, Kopete::OnlineStatus> contactStatus;
+	Kopete::ActiveNotifications typingNotifications;
 	Kopete::Protocol *mProtocol;
 	bool isEmpty;
 	bool mCanBeDeleted;
@@ -96,14 +98,14 @@ Kopete::ChatSession::ChatSession( const Kopete::Contact *user,
 		addContact( others[i], true );
 
 	connect( Kopete::PluginManager::self(), SIGNAL(pluginLoaded(Kopete::Plugin*)), this, SLOT(clearChains()) );
-	connect( Kopete::PluginManager::self(), SIGNAL(pluginUnloaded(const QString&)), this, SLOT(clearChains()) );
+	connect( Kopete::PluginManager::self(), SIGNAL(pluginUnloaded(QString)), this, SLOT(clearChains()) );
 
 	connect( user, SIGNAL(contactDestroyed(Kopete::Contact*)), this, SLOT(slotMyselfDestroyed(Kopete::Contact*)) );
-	connect( user, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ), this,
-		SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
+	connect( user, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)), this,
+		SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
 
 	if( user->metaContact() )
-		connect( user->metaContact(), SIGNAL( photoChanged() ), this, SIGNAL( photoChanged() ) );
+		connect( user->metaContact(), SIGNAL(photoChanged()), this, SIGNAL(photoChanged()) );
 
 	slotUpdateDisplayName();
 }
@@ -131,8 +133,8 @@ void Kopete::ChatSession::setContactOnlineStatus( const Kopete::Contact *contact
 {
 	Kopete::OnlineStatus oldStatus = d->contactStatus[ contact ];
 	d->contactStatus[ contact ] = status;
-	disconnect( contact, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-		this, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus &) ) );
+	disconnect( contact, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+		this, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
 	emit onlineStatusChanged( (Kopete::Contact*)contact, status, oldStatus );
 }
 
@@ -453,18 +455,18 @@ void Kopete::ChatSession::addContact( const Kopete::Contact *c, bool suppress )
 			d->contacts.removeAll( old );
 			d->contacts.append( (Kopete::Contact*)c );
 
-			disconnect( old, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-			this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus &) ) );
+			disconnect( old, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+			this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
 
 			if ( old->metaContact() )
 			{
-				disconnect( old->metaContact(), SIGNAL( displayNameChanged( const QString &, const QString & ) ), this, SLOT( slotUpdateDisplayName() ) );
-				disconnect( old->metaContact(), SIGNAL( photoChanged() ), this, SIGNAL( photoChanged() ) );
+				disconnect( old->metaContact(), SIGNAL(displayNameChanged(QString,QString)), this, SLOT(slotUpdateDisplayName()) );
+				disconnect( old->metaContact(), SIGNAL(photoChanged()), this, SIGNAL(photoChanged()) );
 			}
 			else
-				disconnect( old, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ), this, SLOT( slotUpdateDisplayName() ) );
+				disconnect( old, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)), this, SLOT(slotUpdateDisplayName()) );
 
-			disconnect( old, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ), this, SLOT(slotContactPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant) ) );
+			disconnect( old, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)), this, SLOT(slotContactPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)) );
 
 			emit contactAdded( c, suppress );
 			emit contactRemoved( old, QString() );
@@ -475,18 +477,18 @@ void Kopete::ChatSession::addContact( const Kopete::Contact *c, bool suppress )
 			emit contactAdded( c, suppress );
 		}
 
-		connect( c, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-			this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus &) ) );
+		connect( c, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+			this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
 ;
 		if ( c->metaContact() )
 		{
-			connect( c->metaContact(), SIGNAL( displayNameChanged( const QString &, const QString & ) ), this, SLOT( slotUpdateDisplayName() ) );
-			connect( c->metaContact(), SIGNAL( photoChanged() ), this, SIGNAL( photoChanged() ) );
+			connect( c->metaContact(), SIGNAL(displayNameChanged(QString,QString)), this, SLOT(slotUpdateDisplayName()) );
+			connect( c->metaContact(), SIGNAL(photoChanged()), this, SIGNAL(photoChanged()) );
 		}
 		else
-			connect( c, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ), this, SLOT( slotUpdateDisplayName() ) );
-		connect( c, SIGNAL( contactDestroyed( Kopete::Contact * ) ), this, SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
-		connect( c, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ), this, SLOT(slotContactPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant) ) );
+			connect( c, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)), this, SLOT(slotUpdateDisplayName()) );
+		connect( c, SIGNAL(contactDestroyed(Kopete::Contact*)), this, SLOT(slotContactDestroyed(Kopete::Contact*)) );
+		connect( c, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)), this, SLOT(slotContactPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)) );
 
 		slotUpdateDisplayName();
 	}
@@ -508,19 +510,19 @@ void Kopete::ChatSession::removeContact( const Kopete::Contact *c, const QString
 	{
 		d->contacts.removeAll( (Kopete::Contact*)c );
 
-		disconnect( c, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-			this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus &) ) );
+		disconnect( c, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+			this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
 
 		if ( c->metaContact() )
 		{
-			disconnect( c->metaContact(), SIGNAL( displayNameChanged( const QString &, const QString & ) ), this, SLOT( slotUpdateDisplayName() ) );
-			disconnect( c->metaContact(), SIGNAL( photoChanged() ), this, SIGNAL( photoChanged() ) );
+			disconnect( c->metaContact(), SIGNAL(displayNameChanged(QString,QString)), this, SLOT(slotUpdateDisplayName()) );
+			disconnect( c->metaContact(), SIGNAL(photoChanged()), this, SIGNAL(photoChanged()) );
 		}
 		else
-			disconnect( c, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ), this, SLOT( slotUpdateDisplayName() ) );
-		disconnect( c, SIGNAL( contactDestroyed( Kopete::Contact * ) ), this, SLOT( slotContactDestroyed( Kopete::Contact * ) ) );
+			disconnect( c, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)), this, SLOT(slotUpdateDisplayName()) );
+		disconnect( c, SIGNAL(contactDestroyed(Kopete::Contact*)), this, SLOT(slotContactDestroyed(Kopete::Contact*)) );
 
-		disconnect( c, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ), this, SLOT(slotContactPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant) ) );
+		disconnect( c, SIGNAL(propertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)), this, SLOT(slotContactPropertyChanged(Kopete::PropertyContainer*,QString,QVariant,QVariant)) );
 
 		slotUpdateDisplayName();
 	}
@@ -532,38 +534,62 @@ void Kopete::ChatSession::removeContact( const Kopete::Contact *c, const QString
 
 void Kopete::ChatSession::receivedTypingMsg( const Kopete::Contact *c, bool t )
 {
-	if ( t )
+	emit remoteTyping( c, t );
+
+	QWidget *viewWidget = 0L;
+	bool isActiveWindow = false;
+
+	if ( !account()->isAway() || Kopete::BehaviorSettings::self()->enableEventsWhileAway() )
 	{
-		QWidget *viewWidget = 0L;
-		bool isActiveWindow = false;
-
-		if ( !account()->isAway() || Kopete::BehaviorSettings::self()->enableEventsWhileAway() )
-		{
-			viewWidget = dynamic_cast<QWidget*>(view(false));
-			isActiveWindow = view(false) && ( viewWidget && viewWidget->isActiveWindow() ) ;
-		}
-
-		if ( ! isActiveWindow )
-		{
-			KNotification * notification = new KNotification ( "user_is_typing_message", Kopete::UI::Global::mainWidget() );
-			notification->setText( i18n("User <i>%1</i> is typing a message", c->nickName()) );
-			notification->setPixmap( QPixmap::fromImage( c->metaContact()->picture().image() ) );
-			notification->setActions( QStringList( i18nc("@action", "Chat") ) );
-
-			notification->addContext( qMakePair( QString::fromLatin1("contact"), c->metaContact()->metaContactId().toString() ) );
-			foreach( Kopete::Group *g , c->metaContact()->groups() )
-			{
-				notification->addContext( qMakePair( QString::fromLatin1("group") , QString::number( g->groupId() ) ) );
-			}
-
-			connect( notification, SIGNAL(activated(unsigned int)) , c, SLOT(execute()) );
-			notification->sendEvent();
-		}
+		viewWidget = dynamic_cast<QWidget*>(view(false));
+		isActiveWindow = view(false) && ( viewWidget && viewWidget->isActiveWindow() );
 	}
 
-	emit remoteTyping( c, t );
+	// We aren't interested in notification from current window
+	// or 'user stopped typing' notifications
+	if ( isActiveWindow || !t )
+	{
+		return;
+	}
+
+	// If there is a notification in d->typingNotifications, then we should show it and quit
+	Kopete::ActiveNotifications::iterator notifyIt =
+		d->typingNotifications.find( c->account()->accountLabel() + c->contactId() );
+	if (notifyIt != d->typingNotifications.end())
+	{
+		( *notifyIt )->showNotification();
+		return;
+	}
+
+	KNotification *notification = new KNotification( "user_is_typing_message", viewWidget );
+	const QString msgBody = i18n( "User <i>%1</i> is typing a message", c->nickName() );
+	notification->setText( msgBody );
+	notification->setPixmap( QPixmap::fromImage( c->metaContact()->picture().image() ) );
+	notification->setActions( QStringList( i18nc("@action", "Chat") ) );
+
+	new Kopete::ActiveNotification( notification,
+							c->account()->accountLabel() + c->contactId(),
+							d->typingNotifications,
+							"",
+							msgBody );
+
+	Kopete::MetaContact *mc = c->metaContact();
+	if ( mc )
+	{
+		notification->addContext( qMakePair( QString::fromLatin1("contact"), mc->metaContactId().toString() ) );
+		foreach( Kopete::Group *g , mc->groups() )
+		{
+			notification->addContext( qMakePair( QString::fromLatin1("group") , QString::number( g->groupId() ) ) );
+		}
+	}
+	connect( notification, SIGNAL(activated(uint)) , c, SLOT(execute()) );
+	// User don't need this notification when view is activate
+	connect( this, SIGNAL(viewActivated(KopeteView*)), notification, SLOT(close()) );
+
+	notification->sendEvent();
 }
 
+
 void Kopete::ChatSession::receivedTypingMsg( const QString &contactId, bool t )
 {
 	int i;
@@ -620,7 +646,8 @@ KopeteView* Kopete::ChatSession::view( bool canCreate, const QString &requestedP
 		d->view = Kopete::ChatSessionManager::self()->createView( this, requestedPlugin );
 		if ( d->view )
 		{
-			connect( d->view->mainWidget(), SIGNAL( closing( KopeteView * ) ), this, SLOT( slotViewDestroyed( ) ) );
+			connect( d->view->mainWidget(), SIGNAL(activated(KopeteView*)), this, SIGNAL(viewActivated(KopeteView*)) );
+			connect( d->view->mainWidget(), SIGNAL(closing(KopeteView*)), this, SLOT(slotViewDestroyed()) );
 		}
 		else
 		{
