@@ -37,6 +37,7 @@
 #include "contact.h"
 
 class Connection;
+class ClientStream;
 class ContactManager;
 class UserDetails;
 class QString;
@@ -54,7 +55,6 @@ namespace Kopete
 namespace Oscar
 {
 class Settings;
-}
 
 class LIBOSCAR_EXPORT Client : public QObject
 {
@@ -104,14 +104,12 @@ public:
 	Oscar::Settings* clientSettings() const;
 
 	/**
-	 * Start a connection to the server using the supplied @ref ClientStream.
+	 * Start a connection to the server
 	 * This is only a transport layer connection.
-	 * @param s initialised connection object to use for the connection.
 	 * @param host the host name of server to connect to
 	 * @param port the port of server to connect to
-	 * @param auth indicate whether we're connecting to the authorizer or the bos server
 	 */
-	void connectToServer( Connection *c, const QString& host, quint16 port, bool auth = true );
+	void connectToServer( const QString& host, quint16 port );
 
 	/**
 	 * Start the login process for Oscar
@@ -402,6 +400,8 @@ public:
 	 */
 	FileTransferHandler* createFileTransfer( const QString& contact, const QStringList& files );
 
+	void inviteToChatRoom( const QString& contact, Oscar::WORD exchange, const QString& room, QString msg="Join me in this Chat." );
+
 	/*************
 	  INTERNAL (FOR USE BY TASKS OR CONNECTIONS) METHODS
 	 *************/
@@ -462,6 +462,12 @@ public slots:
 signals:
 	/** CONNECTION EVENTS */
 
+	/** Notifies that we want to create new stream.
+	 * If to clientStream wasn't assigned new ClientStream or this signal isn't
+	 * connected to anything default stream will be created.
+	 */
+	void createClientStream( ClientStream **clientStream );
+
 	/** Notifies that the login process has succeeded. */
 	void loggedIn();
 
@@ -625,6 +631,10 @@ private:
 	/** Delete the static tasks */
 	void deleteStaticTasks();
 
+	/** Start a connection */
+	void connectToServer( Connection *c, const QString& host, quint16 port );
+
+	ClientStream* createClientStream();
 	Connection* createConnection();
 
 	/**
@@ -638,7 +648,8 @@ private:
 	class ClientPrivate;
 	ClientPrivate* d;
 };
-Q_DECLARE_OPERATORS_FOR_FLAGS(Client::ICQStatus)
+}
+Q_DECLARE_OPERATORS_FOR_FLAGS(Oscar::Client::ICQStatus)
 
 #endif
 
